@@ -41,10 +41,10 @@ class ToolsWidget (qt.QWidget):
 
         self.create(parent, ClientObj)
 
-        self.move(window.geometry().x() + window.geometry().width() / 2 \
-                  - self.size().width() / 2, \
-                  window.geometry().y() + window.geometry().height() / 2 \
-                  - self.size().height() / 2)
+        self.move(int(window.geometry().x() + window.geometry().width() / 2 \
+                  - self.size().width() / 2), \
+                  int(window.geometry().y() + window.geometry().height() / 2 \
+                  - self.size().height() / 2))
     gui_signal = qt.Signal()
     other_signal = qt.Signal()
 
